# Generated by Django 2.0.9 on 2018-10-28 15:30

import accounts.models
import autoslug.fields
from django.conf import settings
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import guichet.models
import martor.models
import multiselectfield.db.fields
import re
import uuid


def create_no_account_line(apps, schema_editor):
    PaypalAccount = apps.get_model("guichet", "PaypalAccount")
    db_alias = schema_editor.connection.alias
    if not PaypalAccount.objects.using(db_alias).filter(no_account=True).exists():
        PaypalAccount(email="no_account@billetterie.inpt.fr", no_account=True).save()


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('accounts', '0022_auto_20180621_1813'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='PaypalAccount',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('email', models.EmailField(max_length=254, unique=True)),
                ('description', models.CharField(max_length=100, verbose_name='Description du compte PayPal')),
                ('no_account', models.BooleanField(default=False, editable=False)),
                ('secure_form', models.BooleanField(default=False)),
                ('cert_id', models.CharField(blank=True, max_length=32)),
                ('cert_path_pub', models.CharField(blank=True, max_length=100)),
                ('cert_path_priv', models.CharField(blank=True, max_length=100)),
                ('cert_end_date', models.DateTimeField(default=django.utils.timezone.now)),
            ],
            options={
                'ordering': ['-no_account'],
            },
        ),
        migrations.RunPython(create_no_account_line),
        migrations.CreateModel(
            name='Event',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=32, verbose_name='Nom de l’évènement')),
                ('description', martor.models.MartorField(blank=True, default="Aucune description de l'évènement n'a été fournie.\nPour obtenir plus d'information, contactez l'organisateur de l'évènement.", verbose_name='Description de l’évènement')),
                ('email_message', models.TextField(blank=True, default="Vous trouverez ci-joint votre/vos billets :\nCeux-ci sont nominatifs et doivent être imprimés pour garantir l'accès à l'évènement.\n\nVous pouvez à tout moment télécharger à nouveau ces billets dans la rubrique « Mes Places » de la billetterie INPT.", verbose_name='Message envoyé par email avec les billets')),
                ('other_payment_description', models.TextField(blank=True, default="Aucune information complémentaire sur les moyens de paiement n'est disponible. Pour obtenir plus d'information, contactez l'organisateur de l'évènement.", verbose_name='Description des autres moyens de paiement acceptés que PayPal')),
                ('terms_of_use', models.TextField(blank=True, default="Pour obtenir une copie des conditions d'utilisation de la billetterie et des conditions de vente spécifiques à cet évènement, veuillez contacter l'organisateur de l'évènement.\n\nNotez que pour réaliser un achat sur la billetterie INPT, vous devez avoir lu et accepté ces conditions.", verbose_name='Description des conditions d’utilisation de la billetterie')),
                ('start_date', models.DateTimeField(verbose_name='Date et heure de début')),
                ('end_date', models.DateTimeField(verbose_name='Date et heure de fin')),
                ('event_confidentiality', models.IntegerField(choices=[(1, 'Évènement public'), (2, 'Évènement réservé aux membres connectés'), (3, 'Évènement privé (restriction par club)'), (4, 'Évènement caché (non listé)')], default=1, verbose_name='Confidentialité de l’évènement')),
                ('limit_godson', models.PositiveIntegerField(default=0, verbose_name='Nombre de parrainage autorisé par personne (0 = pas de parrainage)')),
                ('limit_ticket', models.PositiveIntegerField(default=0, verbose_name="Nombre de billet maximum pour l'évènement (0 = non limité)")),
                ('email_event', models.EmailField(max_length=254, verbose_name="Email de contact de l'organisation (assistance aux participants)")),
                ('short_url', autoslug.fields.AutoSlugField(default=None, editable=True, max_length=32, null=True, populate_from='name', slugify=guichet.models.short_url_slug, unique=True, validators=[guichet.models.short_url_validate])),
                ('archived', models.BooleanField(default=False)),
                ('archived_stats', models.TextField(blank=True, default='')),
            ],
            options={
                'ordering': ['start_date'],
            },
        ),
        migrations.CreateModel(
            name='GroupManager',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('access', models.IntegerField(choices=[(1, 'Accès en lecture'), (2, 'Accès en lecture et gestion des entrées'), (3, 'Droit de gestion complet sauf permission'), (4, 'Droit de gestion complet')], default=1, verbose_name='Droit de gestion')),
                ('bureau_only', models.BooleanField(default=False, verbose_name='Uniquement le bureau')),
                ('event', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='guichet.Event')),
                ('group', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='accounts.Group', verbose_name='Groupe')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Info_Sup',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=32, verbose_name='Nom')),
                ('description', models.TextField(blank=True, verbose_name='Description du document à fournir et information de transmision')),
                ('after_payement', models.BooleanField(default=False, verbose_name="Peut être validé après le paiement de la réservation (le billet ne sera imprimable qu'après validation)")),
                ('type_info', models.IntegerField(choices=[(0, "Case à cocher dans l'interface d'administration"), (1, 'Champ texte sur une ligne (max 128 caractères)'), (2, 'Champ texte multi-lignes'), (3, 'Choix dans une liste'), (4, 'Nombre entier'), (5, 'Nombre réel'), (6, 'Fichier')], default=0)),
                ('info_validate', models.BooleanField(default=False, verbose_name="Auto-validation du champ dès qu'il est saisi. Si des informations sont en attentes au moment de l'activation, elles seront automatiquement validées.")),
                ('info_editable', models.BooleanField(default=False, verbose_name='Information modifiable si elle est validée (uniquement si auto-validation)')),
            ],
            options={
                'verbose_name': 'Information supplémentaire (tous)',
                'verbose_name_plural': 'Informations supplémentaires (tous)',
            },
        ),
        migrations.CreateModel(
            name='Info_Sup_Choice_Choices',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=32, verbose_name='Choix')),
            ],
        ),
        migrations.CreateModel(
            name='Info_Sup_Recv',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('state', models.IntegerField(choices=[(0, 'Accepté'), (1, 'En attente'), (2, 'Rejeté'), (3, 'Manquante')], default=3)),
                ('version', models.UUIDField(default=uuid.uuid4)),
            ],
            options={
                'verbose_name': 'Information supplémentaire reçue (tous)',
                'verbose_name_plural': 'Informations supplémentaires reçues (tous)',
            },
        ),
        migrations.CreateModel(
            name='LogEntry',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('date', models.DateTimeField(auto_now_add=True)),
                ('reason', models.IntegerField(choices=[(0, 'Sans attribut'), (1, 'Paiement paypal reçu'), (2, 'Erreur Paiement paypal'), (3, 'Paiement manuel'), (4, "Action d'opposition admin"), (5, 'Billet scanné'), (6, 'Gestion des administrateurs'), (7, "Reception d'information complémentaire"), (8, "Modification d'un paramètre important sur l'évènement"), (9, "Impression billet par l'interface admin"), (10, "Force les limites d'un billet")], default=0)),
                ('operation', models.TextField()),
                ('event', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='logs', to='guichet.Event')),
            ],
        ),
        migrations.CreateModel(
            name='Option',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=32, verbose_name='Nom')),
                ('price', models.DecimalField(decimal_places=2, max_digits=6, validators=[django.core.validators.MinValueValidator(0.0, message='Le prix d’une option doit être positif ou nul.')], verbose_name='Prix')),
                ('description', models.TextField(blank=True, verbose_name='Description de l’option')),
                ('group_name', models.CharField(blank=True, max_length=64, null=True, verbose_name='Nom du groupe d’option (optionnel, nécessaire que dans le cas d’options mutuellement exclusives)')),
                ('group', models.IntegerField(blank=True, default=None, null=True, verbose_name='Numéro du groupe (optionnel, nécessaire que dans les cas d’options mutuellement exclusives)')),
                ('admin_only', models.BooleanField(default=False, verbose_name="Option uniquement visible par les administrateurs de l'événement.")),
                ('mandatory', models.BooleanField(default=False, verbose_name="Option obligatoire (l'une des options doit être gratuite et disponible)")),
            ],
        ),
        migrations.CreateModel(
            name='Registration',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('barcode', models.CharField(max_length=64)),
                ('payee', models.CharField(max_length=64, null=True)),
                ('info_state', models.IntegerField(choices=[(0, 'Manque des informations avant le paiement'), (1, "Manque des informations avant l'évènement"), (2, 'Toutes les informations ont été fournies')], default=0)),
                ('purchase_date', models.DateTimeField(auto_now_add=True)),
                ('paid', models.BooleanField(default=False)),
                ('payment_method', models.IntegerField(choices=[(0, 'Inconnu'), (1, 'Paypal'), (2, 'Liquide'), (3, 'Chèque'), (4, 'CB'), (5, 'Virement')], default=0)),
                ('payment_date', models.DateTimeField(null=True)),
                ('conditions_accepted', models.NullBooleanField()),
                ('opposed', models.BooleanField(default=False)),
                ('reason_opposed', models.IntegerField(choices=[(0, 'Mise en opposition pour une raison inconnue'), (1, "Mise en opposition par un administrateur de l'évènement"), (2, 'Mise en opposition lors du paiement par paypal')], default=0)),
                ('used', models.BooleanField(default=False)),
                ('used_date', models.DateTimeField(null=True)),
                ('options', models.ManyToManyField(blank=True, related_name='options_registration', to='guichet.Option')),
                ('owner', models.ForeignKey(on_delete=models.SET(accounts.models.User.get_anonyme_user), related_name='registrations', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='Ticket',
            fields=[
                ('primarykey', models.AutoField(primary_key=True, serialize=False)),
                ('id', models.IntegerField(editable=False)),
                ('name', models.CharField(max_length=32, verbose_name='Nom')),
                ('short_notes', models.CharField(blank=True, max_length=256, verbose_name='Remarques (courtes, liste des billets)')),
                ('long_notes', models.TextField(blank=True, default='', verbose_name='Remarques (longues, page de confirmation)')),
                ('price', models.DecimalField(decimal_places=2, default=0, max_digits=6, validators=[django.core.validators.MinValueValidator(0.0, message='Le prix d’un billet doit être positif ou nul.')], verbose_name='Prix (0 pour un billet gratuit)')),
                ('limit', models.PositiveIntegerField(default=0, verbose_name='Nombre de place disponible (0 = illimité)')),
                ('min_purchase_date', models.DateTimeField(blank=True, null=True, verbose_name='Date début de vente')),
                ('max_purchase_date', models.DateTimeField(blank=True, null=True, verbose_name='Date limite d’achat (si prévente)')),
                ('online_payment', models.BooleanField(default=True, verbose_name='Paiement en ligne possible')),
                ('allowed_external', models.BooleanField(default=False)),
                ('required_school', models.IntegerField(choices=[(1, 'Étudiants INP (toute école)'), (2, 'Étudiants N7'), (3, 'Étudiants ENSAT'), (4, 'Étudiants A7')], default=1, verbose_name='Restriction par école')),
                ('year_choice', multiselectfield.db.fields.MultiSelectField(blank=True, choices=[(1, 'Étudiants en première année'), (2, 'Étudiants en deuxième année'), (3, 'Étudiants en troisième année'), (4, "Diplomés de l'année courante"), (5, 'Diplomés des années précédentes')], max_length=9, verbose_name='Restriction par année')),
                ('required_ae', models.BooleanField(default=True, verbose_name='Réserver ce billet aux adhérents AE')),
                ('allowed_godson', models.BooleanField(default=False, verbose_name='Ce billet est accessible aux personnes parrainées')),
                ('design', models.ImageField(blank=True, null=True, upload_to=guichet.models.path_design, validators=[guichet.models.FileValidator(), guichet.models.FileSizeValidator()], verbose_name='Template du billet')),
                ('admin_ticket', models.BooleanField(default=False, verbose_name='Seul un manager peut donner ce billet')),
                ('allow_anonyme', models.BooleanField(default=False, verbose_name='Vente sur Place sans compte billetterie (certaines restrictions ne pourront pas être vérifiées)')),
                ('event', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='tickets', to='guichet.Event')),
                ('groups', models.ManyToManyField(blank=True, related_name='authorized_groups', to='accounts.Group', verbose_name='Restriction par groupe')),
            ],
            options={
                'ordering': ['id'],
            },
        ),
        migrations.CreateModel(
            name='UserManager',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('access', models.IntegerField(choices=[(1, 'Accès en lecture'), (2, 'Accès en lecture et gestion des entrées'), (3, 'Droit de gestion complet sauf permission'), (4, 'Droit de gestion complet')], default=1, verbose_name='Droit de gestion')),
                ('event', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='guichet.Event')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Info_Sup_Choice',
            fields=[
                ('info_sup_ptr', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='info_sup_choice', serialize=False, to='guichet.Info_Sup')),
            ],
            options={
                'verbose_name': 'Information supplémentaire (Choix)',
                'verbose_name_plural': 'Informations supplémentaires (Choix)',
            },
            bases=('guichet.info_sup',),
        ),
        migrations.CreateModel(
            name='Info_Sup_File',
            fields=[
                ('info_sup_ptr', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='info_sup_file', serialize=False, to='guichet.Info_Sup')),
                ('file_name', models.CharField(max_length=32, validators=[django.core.validators.RegexValidator(re.compile('^[-a-zA-Z0-9_]+\\Z'), "Enter a valid 'slug' consisting of letters, numbers, underscores or hyphens.", 'invalid')], verbose_name='Nom du fichier (nom interne)')),
            ],
            options={
                'verbose_name': 'Information supplémentaire (Fichier)',
                'verbose_name_plural': 'Informations supplémentaires (Fichier)',
            },
            bases=('guichet.info_sup',),
        ),
        migrations.CreateModel(
            name='Info_Sup_Float',
            fields=[
                ('info_sup_ptr', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='info_sup_float', serialize=False, to='guichet.Info_Sup')),
                ('min_value', models.FloatField(blank=True, null=True, verbose_name='Valeur minimale (laissé vide si pas de minimum)')),
                ('max_value', models.FloatField(blank=True, null=True, verbose_name='Valeur maximale (laissé vide si pas de maximum)')),
            ],
            options={
                'verbose_name': 'Information supplémentaire (Réel)',
                'verbose_name_plural': 'Informations supplémentaires (Réel)',
            },
            bases=('guichet.info_sup',),
        ),
        migrations.CreateModel(
            name='Info_Sup_Int',
            fields=[
                ('info_sup_ptr', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='info_sup_int', serialize=False, to='guichet.Info_Sup')),
                ('min_value', models.IntegerField(blank=True, null=True, verbose_name='Valeur minimale (laissé vide si pas de minimum)')),
                ('max_value', models.IntegerField(blank=True, null=True, verbose_name='Valeur maximale (laissé vide si pas de maximum)')),
            ],
            options={
                'verbose_name': 'Information supplémentaire (Entier)',
                'verbose_name_plural': 'Informations supplémentaires (Entier)',
            },
            bases=('guichet.info_sup',),
        ),
        migrations.CreateModel(
            name='Info_Sup_Recv_Choice',
            fields=[
                ('info_sup_recv_ptr', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='info_sup_recv_choice', serialize=False, to='guichet.Info_Sup_Recv')),
                ('choice', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='guichet.Info_Sup_Choice_Choices')),
            ],
            options={
                'verbose_name': 'Information Supplémentaire Reçue (Choix)',
                'verbose_name_plural': 'Informations supplémentaires reçues (Choix)',
            },
            bases=('guichet.info_sup_recv',),
        ),
        migrations.CreateModel(
            name='Info_Sup_Recv_File',
            fields=[
                ('info_sup_recv_ptr', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='info_sup_recv_file', serialize=False, to='guichet.Info_Sup_Recv')),
                ('upload_file', models.FileField(blank=True, max_length=128, null=True, upload_to=guichet.models.path_info_recv, verbose_name='Document fourni')),
            ],
            options={
                'verbose_name': 'Information Supplémentaire Reçue (Fichier)',
                'verbose_name_plural': 'Informations supplémentaires reçues (Fichier)',
            },
            bases=('guichet.info_sup_recv',),
        ),
        migrations.CreateModel(
            name='Info_Sup_Recv_Float',
            fields=[
                ('info_sup_recv_ptr', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='info_sup_recv_float', serialize=False, to='guichet.Info_Sup_Recv')),
                ('raw_value', models.FloatField(null=True)),
            ],
            options={
                'verbose_name': 'Information Supplémentaire Reçue (Réel)',
                'verbose_name_plural': 'Informations supplémentaires reçues (Réel)',
            },
            bases=('guichet.info_sup_recv',),
        ),
        migrations.CreateModel(
            name='Info_Sup_Recv_Int',
            fields=[
                ('info_sup_recv_ptr', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='info_sup_recv_int', serialize=False, to='guichet.Info_Sup_Recv')),
                ('raw_value', models.IntegerField(null=True)),
            ],
            options={
                'verbose_name': 'Information Supplémentaire Reçue (Entier)',
                'verbose_name_plural': 'Informations supplémentaires reçues (Entier)',
            },
            bases=('guichet.info_sup_recv',),
        ),
        migrations.CreateModel(
            name='Info_Sup_Recv_Long_Text',
            fields=[
                ('info_sup_recv_ptr', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='info_sup_recv_long_text', serialize=False, to='guichet.Info_Sup_Recv')),
                ('text', models.TextField(blank=True)),
            ],
            options={
                'verbose_name': 'Information supplémentaire reçue (Texte Long)',
                'verbose_name_plural': 'Informations supplémentaires reçues (Texte Long)',
            },
            bases=('guichet.info_sup_recv',),
        ),
        migrations.CreateModel(
            name='Info_Sup_Recv_Short_Text',
            fields=[
                ('info_sup_recv_ptr', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='info_sup_recv_short_text', serialize=False, to='guichet.Info_Sup_Recv')),
                ('text', models.CharField(blank=True, max_length=128)),
            ],
            options={
                'verbose_name': 'Information supplémentaire reçue (Texte court)',
                'verbose_name_plural': 'Informations supplémentaires reçues (Texte court)',
            },
            bases=('guichet.info_sup_recv',),
        ),
        migrations.AddField(
            model_name='registration',
            name='ticket',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='registrations', to='guichet.Ticket'),
        ),
        migrations.AddField(
            model_name='option',
            name='ticket',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='options', to='guichet.Ticket'),
        ),
        migrations.AddField(
            model_name='logentry',
            name='registration',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='logs', to='guichet.Registration'),
        ),
        migrations.AddField(
            model_name='logentry',
            name='user',
            field=models.ForeignKey(on_delete=models.SET(accounts.models.User.get_anonyme_user), related_name='logs', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='info_sup_recv',
            name='reference',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='received', to='guichet.Info_Sup'),
        ),
        migrations.AddField(
            model_name='info_sup_recv',
            name='registration',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='info_sup_received', to='guichet.Registration'),
        ),
        migrations.AddField(
            model_name='info_sup',
            name='ticket',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='infos_sup', to='guichet.Ticket'),
        ),
        migrations.AddField(
            model_name='event',
            name='paypal_account',
            field=models.ForeignKey(on_delete=models.SET(guichet.models.PaypalAccount.default_paypal_account), related_name='paypal_account', to='guichet.PaypalAccount', verbose_name='Email du compte PayPal associé à l’évènement'),
        ),
        migrations.AlterUniqueTogether(
            name='ticket',
            unique_together={('event', 'id')},
        ),
        migrations.AlterUniqueTogether(
            name='info_sup_recv',
            unique_together={('reference', 'registration')},
        ),
        migrations.AddField(
            model_name='info_sup_choice_choices',
            name='info_sup',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='choices', to='guichet.Info_Sup_Choice'),
        ),
        migrations.AlterUniqueTogether(
            name='info_sup_choice_choices',
            unique_together={('info_sup', 'name')},
        ),
    ]
